<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Aún no se han guardado en caché todos los calendarios",
"Everything seems to be completely cached" => "Parece que se ha guardado todo en caché",
"No calendars found." => "No se encontraron calendarios.",
"No events found." => "No se encontraron eventos.",
"Wrong calendar" => "Calendario incorrecto",
"You do not have the permissions to edit this event." => "No tiene permisos para editar este evento.",
"The file contained either no events or all events are already saved in your calendar." => "El archivo no contiene eventos o ya existen en tu calendario.",
"events has been saved in the new calendar" => "Los eventos han sido guardados en el nuevo calendario",
"Import failed" => "Fallo en la importación",
"events has been saved in your calendar" => "eventos se han guardado en tu calendario",
"New Timezone:" => "Nueva zona horaria:",
"Timezone changed" => "Zona horaria cambiada",
"Invalid request" => "Petición no válida",
"Calendar" => "Calendario",
"Deletion failed" => "Falló el borrado",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
"user" => "usuario",
"group" => "grupo",
"Editable" => "Editable",
"Shareable" => "Compartible",
"Deletable" => "Borrable",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Domingo",
"Monday" => "Lunes",
"Tuesday" => "Martes",
"Wednesday" => "Miércoles",
"Thursday" => "Jueves",
"Friday" => "Viernes",
"Saturday" => "Sábado",
"Sun." => "Dom.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mier.",
"Thu." => "Jue.",
"Fri." => "Vie.",
"Sat." => "Sab.",
"January" => "Enero",
"February" => "Febrero",
"March" => "Marzo",
"April" => "Abril",
"May" => "Mayo",
"June" => "Junio",
"July" => "Julio",
"August" => "Agosto",
"September" => "Septiembre",
"October" => "Octubre",
"November" => "Noviembre",
"December" => "Diciembre",
"Jan." => "Ene.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Abr.",
"May." => "May.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ago.",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Nov.",
"Dec." => "Dic.",
"All day" => "Todo el día",
"New Calendar" => "Nuevo calendario",
"Missing or invalid fields" => "Campos inválidos o faltantes",
"Title" => "Título",
"From Date" => "Desde la fecha",
"From Time" => "Desde la hora",
"To Date" => "Hasta la fecha",
"To Time" => "Hasta la hora",
"The event ends before it starts" => "El evento termina antes de que comience",
"There was a database fail" => "Se ha producido un error en la base de datos",
"Birthday" => "Cumpleaños",
"Business" => "Negocios",
"Call" => "Llamada",
"Clients" => "Clientes",
"Deliverer" => "Entrega",
"Holidays" => "Festivos",
"Ideas" => "Ideas",
"Journey" => "Viaje",
"Jubilee" => "Aniversario",
"Meeting" => "Reunión",
"Other" => "Otro",
"Personal" => "Personal",
"Projects" => "Proyectos",
"Questions" => "Preguntas",
"Work" => "Trabajo",
"by" => "por",
"unnamed" => "Sin nombre",
"You do not have the permissions to update this calendar." => "No tiene permisos para actualizar este calendario.",
"You do not have the permissions to delete this calendar." => "No tiene permisos para eliminar este calendario.",
"You do not have the permissions to add to this calendar." => "No tiene permisos para añadir a este calendario.",
"You do not have the permissions to add events to this calendar." => "No tiene permisos para añadir eventos a este calendario.",
"You do not have the permissions to delete this event." => "No tiene permisos para eliminar este evento.",
"Busy" => "Ocupado",
"Public" => "Publico",
"Private" => "Privado",
"Confidential" => "Confidencial",
"Does not repeat" => "No se repite",
"Daily" => "Diariamente",
"Weekly" => "Semanalmente",
"Every Weekday" => "Días de semana laboral",
"Bi-Weekly" => "Cada 2 semanas",
"Monthly" => "Mensualmente",
"Yearly" => "Anualmente",
"never" => "nunca",
"by occurrences" => "por ocurrencias",
"by date" => "por fecha",
"by monthday" => "por día del mes",
"by weekday" => "por día de la semana",
"events week of month" => "eventos de la semana del mes",
"first" => "primer",
"second" => "segundo",
"third" => "tercer",
"fourth" => "cuarto",
"fifth" => "quinto",
"last" => "último",
"by events date" => "por fecha de los eventos",
"by yearday(s)" => "por día(s) del año",
"by weeknumber(s)" => "por número(s) de semana",
"by day and month" => "por día y mes",
"Date" => "Fecha",
"Cal." => "Cal.",
"Week" => "Semana",
"Month" => "Mes",
"List" => "Lista",
"Today" => "Hoy",
"Settings" => "Ajustes",
"Your calendars" => "Tus calendarios",
"CalDav Link" => "Enlace a CalDav",
"Share Calendar" => "Compartir calendario",
"Download" => "Descargar",
"Edit" => "Editar",
"Delete" => "Eliminar",
"New calendar" => "Nuevo calendario",
"Edit calendar" => "Editar calendario",
"Displayname" => "Nombre",
"Active" => "Activo",
"Calendar color" => "Color del calendario",
"Save" => "Guardar",
"Submit" => "Guardar",
"Cancel" => "Cancelar",
"Edit an event" => "Editar un evento",
"Export" => "Exportar",
"Eventinfo" => "Información del evento",
"Repeating" => "Repetición",
"Alarm" => "Alarma",
"Attendees" => "Asistentes",
"Share" => "Compartir",
"Title of the Event" => "Título del evento",
"Category" => "Categoría",
"Separate categories with commas" => "Separar categorías con comas",
"Edit categories" => "Editar categorías",
"Access Class" => "Clase de acceso",
"All Day Event" => "Todo el día",
"From" => "Desde",
"To" => "Hasta",
"Advanced options" => "Opciones avanzadas",
"Location" => "Lugar",
"Location of the Event" => "Lugar del evento",
"Description" => "Descripción",
"Description of the Event" => "Descripción del evento",
"Repeat" => "Repetir",
"Advanced" => "Avanzado",
"Select weekdays" => "Seleccionar días de la semana",
"Select days" => "Seleccionar días",
"and the events day of year." => "y el día del año de los eventos.",
"and the events day of month." => "y el día del mes de los eventos.",
"Select months" => "Seleccionar meses",
"Select weeks" => "Seleccionar semanas",
"and the events week of year." => "y la semana del año de los eventos.",
"Interval" => "Intervalo",
"End" => "Fin",
"occurrences" => "ocurrencias",
"create a new calendar" => "Crear un nuevo calendario",
"Import a calendar file" => "Importar un archivo de calendario",
"Please choose a calendar" => "Por favor, escoge un calendario",
"Name of new calendar" => "Nombre del nuevo calendario",
"Take an available name!" => "¡Elige un nombre disponible!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ya existe un calendario con este nombre. Si continúas, se combinarán los calendarios.",
"Remove all events from the selected calendar" => "Eliminar todos los eventos del calendario seleccionado",
"Import" => "Importar",
"Close Dialog" => "Cerrar diálogo",
"Create a new event" => "Crear un nuevo evento",
"Share with:" => "Compartir con:",
"Shared with" => "Compartir con",
"Unshare" => "Dejar de compartir",
"Nobody" => "Nadie",
"Shared via calendar" => "Compartir via calendario",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "NOTA: las acciones sobre eventos compartidos a través del calendario afectarán a la compartición de todo el calendario.",
"View an event" => "Ver un evento",
"No categories selected" => "Ninguna categoría seleccionada",
"of" => "de",
"at" => "a las",
"General" => "General",
"Timezone" => "Zona horaria",
"Update timezone automatically" => "Actualizar zona horaria automáticamente",
"Time format" => "Formato de hora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Comenzar semana el",
"Cache" => "Caché",
"Clear cache for repeating events" => "Limpiar caché de eventos recurrentes",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Direcciones de sincronización de calendario CalDAV:",
"more info" => "Más información",
"Primary address (Kontact et al)" => "Dirección principal (Kontact y otros)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Enlace(s) iCalendar de sólo lectura"
);
